@@ -1,36 +1,21 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012 Martin Kuettler <martin.kuettler@gmail.com>
+*/
 
 #include "animationresultitem.h"
 #include "commandentry.h"
+#include "worksheetview.h"
 #include "lib/result.h"
 #include "lib/animationresult.h"
 
-#include <QDebug>
 #include <QFileDialog>
 #include <QMovie>
 
 #include <KLocalizedString>
 
 AnimationResultItem::AnimationResultItem(QGraphicsObject* parent, Cantor::Result* result)
-    : WorksheetImageItem(parent), ResultItem(result), m_height(0), m_movie(nullptr)
+    : WorksheetImageItem(parent), ResultItem(result)
 {
     update();
 }
@@ -60,7 +45,7 @@ void AnimationResultItem::populateMenu(QMenu* menu, QPointF pos)
             menu->addAction(QIcon::fromTheme(QLatin1String("media-playback-stop")), i18n("Stop"),
                             this, SLOT(stopMovie()));
     }
-    qDebug() << "populate Menu";
+
     emit menuCreated(menu, mapToParent(pos));
 }
 
@@ -127,7 +112,6 @@ void AnimationResultItem::saveResult()
 {
     Cantor::Result* res = result();
     const QString& filename=QFileDialog::getSaveFileName(worksheet()->worksheetView(), i18n("Save result"), QString(), res->mimeType());
-    qDebug()<<"saving result to "<<filename;
     res->save(filename);
 }
 
