@@ -1,21 +1,8 @@
 /*
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 #ifndef CANTOR_H
@@ -32,7 +19,6 @@
 #include "lib/panelplugin.h"
 
 class QTabWidget;
-class KTextEdit;
 class KRecentFilesAction;
 
 namespace Cantor{
@@ -84,22 +70,23 @@ Q_SIGNALS:
     void hierarhyEntryNameChange(QString, QString, int);
     void requestScrollToHierarchyEntry(QString);
     void settingsChanges();
+    void requestDocumentation(const QString&);
 
 public Q_SLOTS:
-    void addWorksheet(const QString& backendName);
+    void addWorksheet(const QString&);
     /// Use this method/slot to load whatever file/URL you have
-    void load(const QUrl& url);
+    void load(const QUrl&);
 
 private Q_SLOTS:
     void fileNew();
     void fileOpen();
-    void onWorksheetSave(const QUrl& url);
+    void onWorksheetSave(const QUrl&);
     void optionsConfigureKeys();
 
     void activateWorksheet(int index);
 
-    void setTabCaption(const QString& tab, const QIcon& icon);
-    void updateBackendForPart(const QString& backend);
+    void setTabCaption(const QString&, const QIcon&);
+    void updateBackendForPart(const QString&);
     void closeTab(int index = -1);
 
     void showSettings();
@@ -112,30 +99,29 @@ private Q_SLOTS:
     void updateNewSubmenu();
 
     void pluginVisibilityRequested();
-    void pluginCommandRunRequested(const QString& cmd);
+    void pluginCommandRunRequested(const QString&);
 
 private:
     void setupActions();
     void closeEvent(QCloseEvent*) override;
     bool reallyClose(bool checkAllParts = true);
-    bool reallyCloseThisPart(KParts::ReadWritePart* part);
-    void updateWindowTitle(const QString& fileName);
-    void saveDockPanelsState(KParts::ReadWritePart* part);
-    KParts::ReadWritePart* findPart(QWidget* widget);
+    bool reallyCloseThisPart(KParts::ReadWritePart*);
+    void updateWindowTitle(const QString&);
+    void saveDockPanelsState(KParts::ReadWritePart*);
+    KParts::ReadWritePart* findPart(QWidget*);
 
 private:
     QMap<KParts::ReadWritePart*, QStringList> m_pluginsVisibility;
     QMap<KParts::ReadWritePart*, Cantor::PanelPluginHandler::PanelStates> m_pluginsStates;
-    QList<KParts::ReadWritePart *> m_parts;
+    QList<KParts::ReadWritePart*> m_parts;
     QMap<KParts::ReadWritePart*, QString> m_parts2Backends;
-    KParts::ReadWritePart* m_part;
+    KParts::ReadWritePart* m_part{nullptr};
     QTabWidget* m_tabWidget;
     QList<QDockWidget*> m_panels;
     QList<QAction*> m_newBackendActions;
-    QDockWidget* m_helpDocker;
     KRecentFilesAction* m_recentProjectsAction;
 
-    Cantor::PanelPluginHandler m_panelHandler;
+    Cantor::PanelPluginHandler m_panelHandler{nullptr};
 
     // For better UX: set previous used filter in "Open" action as default filter
     QString m_previousFilter;
