@@ -97,7 +97,6 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     m_initProgressDlg(nullptr),
     m_showProgressDlg(true),
     m_currectZoomAction(nullptr),
-    m_showBackendHelp(nullptr),
     m_statusBarBlocked(false),
     m_sessionStatusCounter(0)
 {
@@ -135,7 +134,7 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     connect(m_worksheet, &Worksheet::hierarhyEntryNameChange, this, &CantorPart::hierarhyEntryNameChange);
     connect(this, &CantorPart::requestScrollToHierarchyEntry, m_worksheet, &Worksheet::requestScrollToHierarchyEntry);
     connect(this, &CantorPart::settingsChanges, m_worksheet, &Worksheet::handleSettingsChanges);
-    connect(m_worksheet, &Worksheet::requestDocumentation, this, &CantorPart::requestDocumentation);
+    connect(m_worksheet, &Worksheet::requestDocumentation, this, &CantorPart::documentationRequested);
 
     layout->addWidget(m_worksheetview);
     setWidget(widget);
@@ -340,16 +339,6 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     connect(removeCurrent, &QAction::triggered, m_worksheet, &Worksheet::removeCurrentEntry);
     m_editActions.push_back(removeCurrent);
 
-    Cantor::Backend* const backend = Cantor::Backend::getBackend(backendName);
-    m_showBackendHelp = new QAction(i18n("Show Help") , collection);
-    m_showBackendHelp->setIcon(QIcon::fromTheme(backend->icon()));
-    collection->addAction(QLatin1String("backend_help"), m_showBackendHelp);
-    connect(m_showBackendHelp, &QAction::triggered, this, &CantorPart::showBackendHelp);
-
-    // Do not display "Show Backend Help" action for Maxima, since we are showing it's integrated documentation
-    if(backend->name() == QLatin1String("Maxima") || backend->name() == QLatin1String("Octave") || backend->name() == QLatin1String("Python"))
-        m_showBackendHelp->setVisible(false);
-
     // Disabled, because uploading to kde store from program don't work
     // See https://phabricator.kde.org/T9980 for details
     // If this situation will changed, then uncomment this action
@@ -384,7 +373,6 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
 
     if (b)
     {
-        m_showBackendHelp->setText(i18n("Show %1 Help", b->name()));
         showEditor->setEnabled(b->extensions().contains(QLatin1String("ScriptExtension")));
         initialized();
     }
@@ -413,12 +401,6 @@ void CantorPart::setReadOnly()
 {
     for (QAction* action : m_editActions)
         action->setEnabled(false);
-
-    if (m_showBackendHelp)
-    {
-        m_showBackendHelp->setEnabled(false);
-        m_showBackendHelp->setVisible(false);
-    }
 }
 
 void CantorPart::setModified(bool modified)
@@ -469,7 +451,7 @@ bool CantorPart::openFile()
     if (rc) {
         qDebug()<< "Worksheet successfully loaded in " <<  (float)timer.elapsed()/1000 << " seconds";
         updateCaption();
-        if (m_worksheet && m_worksheet->session() && m_worksheet->session()->backend())
+        if (m_worksheet->session() && m_worksheet->session()->backend())
             setBackendName(m_worksheet->session()->backend()->id());
         // We modified, but it we load file now, so no need in save option
         setModified(false);
@@ -743,15 +725,30 @@ void CantorPart::enableTypesetting(bool enable)
     m_worksheet->session()->setTypesettingEnabled(enable);
 }
 
+/*!
+ * called when the current worksheet has requested to show the documentation for \c keyword.
+ * In case the local documentation is available for the current backend, the signal is
+ * forwarded to the shell to show the documentation plugin/widget.
+ * If no local documentation is available, the defaul online URL for the backend documentation
+ * is openned.
+ */
+void CantorPart::documentationRequested(const QString& keyword) {
+    auto* backend = m_worksheet->session()->backend();
+    const KConfigGroup& group = KSharedConfig::openConfig()->group(backend->name().toLower());
+    const auto& docNames = group.readEntry(QLatin1String("Names"), QStringList());
+    if (!docNames.isEmpty())
+        emit requestDocumentation(keyword);
+    else
+        showBackendHelp();
+}
+
 void CantorPart::showBackendHelp()
 {
-    qDebug()<<"Showing backend's help";
     auto* backend = m_worksheet->session()->backend();
-    QUrl url = backend->helpUrl();
-    qDebug()<<"launching url "<<url;
-    auto *job = new KIO::OpenUrlJob(url);
+    auto* job = new KIO::OpenUrlJob(backend->helpUrl());
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
     job->start();
+    delete job;
 }
 
 Worksheet* CantorPart::worksheet()
@@ -901,10 +898,6 @@ void CantorPart::adjustGuiToSession()
     m_typeset->setVisible(false);
 #endif
     m_completion->setVisible(capabilities.testFlag(Cantor::Backend::Completion));
-
-    //this is 0 on the first call
-    if(m_showBackendHelp)
-        m_showBackendHelp->setText(i18n("Show %1 Help", m_worksheet->session()->backend()->name()));
 }
 
 void CantorPart::publishWorksheet()
